<?php
/**
 * @author  Axilweb
 * @since   1.0
 * @version 1.0
 * @package papr-elements
 */


use Elementor\Controls_Manager;
use Elementor\Plugin;
use Elementor\Widget_Base;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;


if (!defined('ABSPATH')) exit; // Exit if accessed directly
class axil_post_carousel_single_column extends Widget_Base
{

    public $axil_name;
    public $axil_base;
    public $axil_category;
    public $axil_icon;

    public function __construct($settings = [], $args = null)
    {
        $this->axil_category = AXIL_ELEMENTS_PRFX . '-widgets'; // Category /@dev
        $this->axil_icon = 'eicon-post-slider';
        $this->axil_name = esc_html__('Papr Posts Carousel Single Column', 'papr-elements');
        $this->axil_base = 'axilnews-post-carousel-single-column';
        parent::__construct($settings, $args);
    }

    public function get_name()
    {
        return $this->axil_base;
    }

    public function get_title()
    {
        return $this->axil_name;
    }

    public function get_icon()
    {
        return $this->axil_icon;
    }

    public function get_categories()
    {
        return array($this->axil_category);
    }

    public function axil_fields()
    {
        $categories = get_categories();
        foreach ($categories as $category) {
            $category_dropdown[$category->slug] = $category->name;
        }

        $fields = array(

            /* News Box Style */
            // Start Section Title
            array(
                'mode' => 'section_start',
                'id' => 'sec_title',
                'label' => esc_html__('Section Title & Button', 'papr-elements'),
            ),
            array(
                'label' => esc_html__('Section Title Show', 'papr-elements'),
                'type' => Controls_Manager::SWITCHER,
                'id' => 'has_sec_title',
                'label_on' => esc_html__('Show', 'papr-elements'),
                'label_off' => esc_html__('Hide', 'papr-elements'),
                'return_value' => 'yes',
                'default' => 'no',
            ),
            array(
                'type' => Controls_Manager::CHOOSE,
                'id' => 'sec_title_tag',
                'label' => esc_html__('Title HTML Tag', 'papr-elements'),
                'options' => array(
                    'h1' => [
                        'title' => esc_html__('H1', 'papr-elements'),
                        'icon' => 'eicon-editor-h1'
                    ],
                    'h2' => [
                        'title' => esc_html__('H2', 'papr-elements'),
                        'icon' => 'eicon-editor-h2'
                    ],
                    'h3' => [
                        'title' => esc_html__('H3', 'papr-elements'),
                        'icon' => 'eicon-editor-h3'
                    ],
                    'h4' => [
                        'title' => esc_html__('H4', 'papr-elements'),
                        'icon' => 'eicon-editor-h4'
                    ],
                    'h5' => [
                        'title' => esc_html__('H5', 'papr-elements'),
                        'icon' => 'eicon-editor-h5'
                    ],
                    'h6' => [
                        'title' => esc_html__('H6', 'papr-elements'),
                        'icon' => 'eicon-editor-h6'
                    ],
                    'div' => [
                        'title' => esc_html__('div', 'papr-elements'),
                        'icon' => 'eicon-font'
                    ]
                ),
                'default' => 'h2',
                'label_block' => true,
                'toggle' => false,
                'condition' => array('has_sec_title' => array('yes')),
            ),
            array(
                'type' => Controls_Manager::TEXTAREA,
                'id' => 'title',
                'label' => esc_html__('Title', 'papr-elements'),
                'default' => 'News',
                'condition' => array('has_sec_title' => array('yes')),
            ),
            array(
                'mode' => 'group',
                'type' => Group_Control_Typography::get_type(),
                'name' => 'section_title_typography',
                'label' => esc_html__('Typography', 'papr-elements'),
                'selector' => '{{WRAPPER}} .axil-title',
                'condition' => array('has_sec_title' => array('yes')),
            ),
            array(
                'type' => Controls_Manager::COLOR,
                'id' => 'title_color',
                'label' => esc_html__('Title Color', 'papr-elements'),
                'selectors' => array(
                    '{{WRAPPER}} .axil-title.axil-title__mid' => 'color: {{VALUE}}',
                ),
                'condition' => array('has_sec_title' => array('yes')),
            ),
            // Link Start
            array(
                'label' => esc_html__('Right Link Button Show', 'papr-elements'),
                'type' => Controls_Manager::SWITCHER,
                'id' => 'has_sec_right_button',
                'label_on' => esc_html__('Show', 'papr-elements'),
                'label_off' => esc_html__('Hide', 'papr-elements'),
                'return_value' => 'yes',
                'default' => 'no',
            ),
            array(
                'id' => 'axil_post_grid_link_text',
                'label' => esc_html__('Button Text', 'papr-elements'),
                'type' => Controls_Manager::TEXT,
                'default' => 'View All Post',
                'title' => esc_html__('Enter button text', 'papr-elements'),
                'condition' => array('has_sec_right_button' => array('yes')),
            ),
            array(
                'id' => 'axil_post_grid_link_type',
                'label' => esc_html__('Button Link Type', 'papr-elements'),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    '1' => esc_html__('Custom Link', 'papr-elements'),
                    '2' => esc_html__('Internal Page', 'papr-elements'),
                    '3' => esc_html__('News Category', 'papr-elements'),
                ],
                'default' => '1',
                'condition' => array('has_sec_right_button' => array('yes')),
            ),
            array(
                'id' => 'axil_post_grid_custom_link',
                'label' => esc_html__('Button link', 'papr-elements'),
                'type' => Controls_Manager::URL,
                'dynamic' => [
                    'active' => true,
                ],
                'placeholder' => esc_html__('https://your-link.com', 'papr-elements'),
                'show_external' => true,
                'default' => [
                    'url' => '#',
                    'is_external' => true,
                    'nofollow' => true,
                ],
                'condition' => [
                    'axil_post_grid_link_type' => '1',
                    'has_sec_right_button' => array('yes')
                ]
            ),
            array(
                'id' => 'axil_post_grid_page_link',
                'label' => esc_html__('Select Button Page', 'papr-elements'),
                'type' => Controls_Manager::SELECT2,
                'options' => axil_get_all_pages(),
                'condition' => [
                    'axil_post_grid_link_type' => '2',
                    'has_sec_right_button' => array('yes')
                ]
            ),
            array(
                'id' => 'axil_post_grid_cat_link',
                'label' => esc_html__('Select Category', 'papr-elements'),
                'type' => Controls_Manager::SELECT2,
                'options' => $category_dropdown,
                'condition' => array(
                    'axil_post_grid_link_type' => array('3'),
                    'has_sec_right_button' => array('yes'),
                ),
            ),

            array(
                'mode' => 'section_end',
            ),
            array(
                'mode' => 'section_start',
                'id' => 'sec_general',
                'label' => esc_html__('Layout', 'papr-elements'),
            ),
            array(
                'type' => Controls_Manager::SELECT2,
                'id' => 'style',
                'label' => esc_html__('Style', 'papr-elements'),
                'options' => array(
                    'style1' => esc_html__('Style 1', 'papr-elements'),
                ),
                'default' => 'style1',
            ),
            array(
                'type' => Controls_Manager::SELECT2,
                'id' => 'image_size',
                'label' => esc_html__('Select Image Size', 'papr-elements'),
                'options' => papr_get_thumbnail_sizes(),
                'label_block' => true,
            ),
            array(
                'type' => Controls_Manager::SLIDER,
                'id' => 'custom-height-layout-1',
                'mode' => 'responsive',
                'label' => esc_html__('Height', 'papr-elements'),
                'size_units' => ['px', '%', 'vh'],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1500,
                        'step' => 1,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                    'vh' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .allow-custom-height .axil-post-carousel .owl-item img' => 'height: {{SIZE}}{{UNIT}};'
                ],
                'condition' => array('style' => array('style1')),
            ),
            array(
                'type' => Controls_Manager::SLIDER,
                'id' => 'content-spacing-left-right',
                'mode' => 'responsive',
                'label' => esc_html__('Padding Left/Right', 'papr-elements'),
                'size_units' => ['px', '%', 'rem'],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1500,
                        'step' => 1,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                        'step' => 1,
                    ],
                    'rem' => [
                        'min' => 0,
                        'max' => 1500,
                        'step' => 1,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .axil-img-container .media-body__big' => 'padding-left: {{SIZE}}{{UNIT}};padding-right: {{SIZE}}{{UNIT}};',
                ],
            ),
            array(
                'type' => Controls_Manager::SLIDER,
                'id' => 'content-spacing-top-bottom',
                'mode' => 'responsive',
                'label' => esc_html__('Padding Top/Bottom', 'papr-elements'),
                'size_units' => ['px', '%', 'rem'],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1500,
                        'step' => 1,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                        'step' => 1,
                    ],
                    'rem' => [
                        'min' => 0,
                        'max' => 1500,
                        'step' => 1,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .axil-img-container .media-body__big' => 'padding-top: {{SIZE}}{{UNIT}};padding-bottom: {{SIZE}}{{UNIT}};',
                ],
            ),
            array(
                'mode' => 'group',
                'type' => Group_Control_Typography::get_type(),
                'name' => 'content_title_typography',
                'label' => esc_html__('Title Typography', 'papr-elements'),
                'selector' => '{{WRAPPER}} .axil-post-title',
            ),
            array(
                'type' => Controls_Manager::CHOOSE,
                'id' => 'content_alignment',
                'label' => esc_html__('Content Alignment', 'papr-elements'),
                'options' => [
                    'text-left' => [
                        'title' => esc_html__( 'Left', 'papr-elements' ),
                        'icon' => 'fa fa-align-left',
                    ],
                    'text-center' => [
                        'title' => esc_html__( 'Center', 'papr-elements' ),
                        'icon' => 'fa fa-align-center',
                    ],
                    'text-right' => [
                        'title' => esc_html__( 'Right', 'papr-elements' ),
                        'icon' => 'fa fa-align-right',
                    ],
                ],
                'toggle' => true,
            ),
            array(
                'type' => Controls_Manager::SWITCHER,
                'id' => 'zoom_effect',
                'label' => esc_html__('Zoom Effect', 'papr-elements'),
                'label_on' => esc_html__('Show', 'papr-elements'),
                'label_off' => esc_html__('Hide', 'papr-elements'),
                'default' => 'yes',
            ),
            array(
                'type' => Controls_Manager::SWITCHER,
                'id' => 'margin_bottom',
                'label' => esc_html__('Margin Bottom', 'papr-elements'),
                'label_on' => esc_html__('Yes', 'papr-elements'),
                'label_off' => esc_html__('No', 'papr-elements'),
                'default' => 'yes',
            ),
            array(
                'mode' => 'section_end',
            ),

            array(
                'mode' => 'section_start',
                'id' => 'sec_query',
                'label' => esc_html__('Query', 'papr-elements'),
            ),
            array(
                'type' => Controls_Manager::SELECT2,
                'id' => 'post_sorting',
                'label' => esc_html__('Post Sorting', 'papr-elements'),
                'options' => array(
                    'recent' => esc_html__('Recent Post', 'papr-elements'),
                    'rand' => esc_html__('Random Post', 'papr-elements'),
                    'modified' => esc_html__('Last Modified Post', 'papr-elements'),
                    'comment_count' => esc_html__('Most commented Post', 'papr-elements'),
                    'view' => esc_html__('Most viewed Post', 'papr-elements'),
                ),
                'default' => 'recent',
            ),
            /* Post Order */
            array(
                'type' => Controls_Manager::SELECT2,
                'id' => 'post_ordering',
                'label' => esc_html__('Post Ordering', 'papr-elements'),
                'options' => array(
                    'DESC' => esc_html__('Desecending', 'papr-elements'),
                    'ASC' => esc_html__('Ascending', 'papr-elements'),
                ),
                'default' => 'DESC',
            ),
            array(
                'type' => Controls_Manager::SELECT2,
                'id' => 'cat_single_list',
                'label' => esc_html__('Categories', 'papr-elements'),
                'options' => $category_dropdown,
                'default' => '0',
                'multiple' => true,
            ),
            array(
                'type' => Controls_Manager::NUMBER,
                'id' => 'number_of_post',
                'label' => esc_html__('Number of Post', 'papr-elements'),
                'default' => '4',
            ),
            array(
                'type' => Controls_Manager::NUMBER,
                'id' => 'offset',
                'label' => esc_html__('Offset', 'papr-elements'),
            ),
            array(
                'type' => Controls_Manager::SELECT2,
                'id' => 'posts_not_in',
                'label' => esc_html__('Select The Posts that will not display', 'papr-elements'),
                'label_block' => true,
                'multiple' => true,
                'separator' => 'before',
                'options' => axil_post_name(),
            ),

            array(
                'mode' => 'section_end',
            ),
            array(
                'mode' => 'section_start',
                'id' => 'sec_meta_query',
                'label' => esc_html__('Display Options', 'papr-elements'),
            ),
            array(
                'type' => Controls_Manager::CHOOSE,
                'id' => 'post_title_tag',
                'label' => esc_html__('Title HTML Tag', 'papr-elements'),
                'options' => array(
                    'h1' => [
                        'title' => esc_html__('H1', 'papr-elements'),
                        'icon' => 'eicon-editor-h1'
                    ],
                    'h2' => [
                        'title' => esc_html__('H2', 'papr-elements'),
                        'icon' => 'eicon-editor-h2'
                    ],
                    'h3' => [
                        'title' => esc_html__('H3', 'papr-elements'),
                        'icon' => 'eicon-editor-h3'
                    ],
                    'h4' => [
                        'title' => esc_html__('H4', 'papr-elements'),
                        'icon' => 'eicon-editor-h4'
                    ],
                    'h5' => [
                        'title' => esc_html__('H5', 'papr-elements'),
                        'icon' => 'eicon-editor-h5'
                    ],
                    'h6' => [
                        'title' => esc_html__('H6', 'papr-elements'),
                        'icon' => 'eicon-editor-h6'
                    ],
                    'div' => [
                        'title' => esc_html__('div', 'papr-elements'),
                        'icon' => 'eicon-font'
                    ]
                ),
                'default' => 'h3',
                'toggle' => false,
                'label_block' => true,
            ),
            array(
                'type' => Controls_Manager::NUMBER,
                'id' => 'post_title_length',
                'label' => esc_html__('Post Title Length', 'papr-elements'),
                'default' => '10',
            ),
            array(
                'mode' => 'group',
                'type' => Group_Control_Typography::get_type(),
                'name' => 'post_title_typography',
                'label' => esc_html__('Post Title Typography', 'papr-elements'),
                'selector' => '{{WRAPPER}} .axil-post-title',
            ),
            array(
                'id' => 'hr-22',
                'type' => Controls_Manager::DIVIDER,
                'style' => 'thick',
            ),
            array(
                'type' => Controls_Manager::SWITCHER,
                'id' => 'cat_display',
                'label' => esc_html__('Category Name Display', 'papr-elements'),
                'label_on' => esc_html__('On', 'papr-elements'),
                'label_off' => esc_html__('Off', 'papr-elements'),
                'default' => 'yes',
                'condition' => array('has_sec_title' => array('yes')),
            ),

            array(
                'type' => Controls_Manager::SWITCHER,
                'id' => 'post_date',
                'label' => esc_html__('Display Post Date', 'papr-elements'),
                'label_on' => esc_html__('Show', 'papr-elements'),
                'label_off' => esc_html__('Hide', 'papr-elements'),
                'default' => 'yes',
                'return_value' => 'yes',
            ),
            array(
                'type' => Controls_Manager::SWITCHER,
                'id' => 'post_author',
                'label' => esc_html__('Display Author Name', 'papr-elements'),
                'label_on' => esc_html__('Show', 'papr-elements'),
                'label_off' => esc_html__('Hide', 'papr-elements'),
                'default' => 'yes',
            ),

            array(
                'type' => Controls_Manager::SWITCHER,
                'id' => 'post_update_date',
                'label' => esc_html__('Display Update Date', 'papr-elements'),
                'label_on' => esc_html__('Show', 'papr-elements'),
                'label_off' => esc_html__('Hide', 'papr-elements'),
                'default' => 'no',
            ),
            array(
                'type' => Controls_Manager::SWITCHER,
                'id' => 'post_view',
                'label' => esc_html__('Display post view', 'papr-elements'),
                'label_on' => esc_html__('Show', 'papr-elements'),
                'label_off' => esc_html__('Hide', 'papr-elements'),
                'default' => 'no',
            ),
            array(
                'type' => Controls_Manager::SWITCHER,
                'id' => 'post_shares',
                'label' => esc_html__('Display post shares', 'papr-elements'),
                'label_on' => esc_html__('Show', 'papr-elements'),
                'label_off' => esc_html__('Hide', 'papr-elements'),
                'default' => 'no',
            ),

            array(
                'type' => Controls_Manager::SWITCHER,
                'id' => 'post_comment',
                'label' => esc_html__('Display Comment Number', 'papr-elements'),
                'label_on' => esc_html__('Show', 'papr-elements'),
                'label_off' => esc_html__('Hide', 'papr-elements'),
                'default' => 'no',
            ),
            /* Hide Thumbnail */
            array(
                'id' => 'hr-2',
                'type' => Controls_Manager::DIVIDER,
                'style' => 'thick',
            ),
            array(
                'type' => Controls_Manager::SWITCHER,
                'id' => 'show_post_thumb',
                'label' => esc_html__('Display Post Thumbnail', 'papr-elements'),
                'label_on' => esc_html__('Show', 'papr-elements'),
                'label_off' => esc_html__('hide', 'papr-elements'),
                'default' => 'yes',
            ),

            array(
                'mode' => 'section_end',
            ),
            array(
                'mode' => 'section_start',
                'id' => 'sec_slider_options',
                'label' => esc_html__('Slider Options', 'papr-elements'),
            ),

            array(
                'type' => Controls_Manager::SWITCHER,
                'id' => 'nav',
                'label' => esc_html__('Navigation', 'papr-elements'),
                'label_on' => esc_html__('Show', 'papr-elements'),
                'label_off' => esc_html__('Hide', 'papr-elements'),
                'default' => 'yes',
            ),
            array(
                'type' => Controls_Manager::SELECT2,
                'id' => 'navigation_style',
                'label' => esc_html__('Navigation Style', 'papr-elements'),
                'options' => array(
                    'style1' => esc_html__('Style 1', 'papr-elements'),
                    'style2' => esc_html__('Style 2', 'papr-elements'),
                ),
                'default' => 'style1',
            ),
            array(
                'type' => Controls_Manager::SWITCHER,
                'id' => 'autoplay',
                'label' => esc_html__('Autoplay', 'papr-elements'),
                'label_on' => esc_html__('Yes', 'papr-elements'),
                'label_off' => esc_html__('No', 'papr-elements'),
                'default' => 'no',
            ),

            array(
                'mode' => 'section_end',
            ),


        );
        return $fields;

    }

    protected function _register_controls()
    {
        $fields = $this->axil_fields();
        foreach ($fields as $field) {
            if (isset($field['mode']) && $field['mode'] == 'section_start') {
                $id = $field['id'];
                unset($field['id']);
                unset($field['mode']);
                $this->start_controls_section($id, $field);
            } elseif (isset($field['mode']) && $field['mode'] == 'section_end') {
                $this->end_controls_section();
            } elseif (isset($field['mode']) && $field['mode'] == 'group') {
                $type = $field['type'];
                unset($field['mode']);
                unset($field['type']);
                $this->add_group_control($type, $field);
            } elseif (isset($field['mode']) && $field['mode'] == 'responsive') {
                $id = $field['id'];
                unset($field['id']);
                unset($field['mode']);
                $this->add_responsive_control($id, $field);
            } else {
                $id = $field['id'];
                unset($field['id']);
                $this->add_control($id, $field);
            }
        }
    }

    protected function render()
    {
        $settings = $this->get_settings();
        $template = 'post-carousel-single-column-' . str_replace("style", "", $settings['style']);
        return Axil_Elements_Helper::axil_element_template($template, $settings);
    }
}