<?php
/**
 * @author  Axilweb
 * @since   1.0
 * @version 1.0
 * @package papr-elements
 */

use Elementor\Controls_Manager;
use Elementor\Plugin;
use Elementor\Widget_Base;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
class axil_post_minimal extends Widget_Base {

    public $axil_name;
    public $axil_base;
    public $axil_category;
    public $axil_icon;
    public $axil_translate;
    public function __construct( $settings = [], $args = null ) {
        $this->axil_category = AXIL_ELEMENTS_PRFX . '-widgets'; // Category /@dev
        $this->axil_icon     = 'eicon-text';
        $this->axil_name = esc_html__( 'Papr Posts Minimal', 'papr-elements' );
        $this->axil_base = 'axilnews-post-minimal';
        $this->axil_translate = array(
            'cols'  => array(
                '12' =>esc_html__( '1 Col', 'papr-elements' ),
                '6'  =>esc_html__( '2 Col', 'papr-elements' ),
                '4'  =>esc_html__( '3 Col', 'papr-elements' ),
                '3'  =>esc_html__( '4 Col', 'papr-elements' ),
                '2'  =>esc_html__( '6 Col', 'papr-elements' ),
            ),
        );
        parent::__construct( $settings, $args );
    }
    public function get_name() {
        return $this->axil_base;
    }
    public function get_title() {
        return $this->axil_name;
    }
    public function get_icon() {
        return $this->axil_icon;
    }
    public function get_categories() {
        return array( $this->axil_category );
    }
    public function axil_fields(){    
        $categories = get_categories();
        foreach ( $categories as $category ) {
            $category_dropdown[$category->slug] = $category->name;
        }     
        $fields = array(               
            array(
                'mode'    => 'section_start',
                'id'      => 'sec_query',
                'label'   => esc_html__( 'Query', 'papr-elements' ),
            ),
            array(
                'type'    => Controls_Manager::SELECT2,
                'id'      => 'post_sorting',
                'label'   => esc_html__( 'Post Sorting', 'papr-elements' ),
                'options' => array(
                    'recent'        => esc_html__( 'Recent Post', 'papr-elements' ),
                    'rand'          => esc_html__( 'Random Post', 'papr-elements' ),
                    'modified'      => esc_html__( 'Last Modified Post', 'papr-elements' ),
                    'comment_count' => esc_html__( 'Most commented Post', 'papr-elements' ),
                    'view'          => esc_html__( 'Most viewed Post', 'papr-elements' ),
                ),
                'default' => 'recent',
            ),      
            array(
                'type'    => Controls_Manager::SELECT2,
                'id'      => 'post_ordering',
                'label'   => esc_html__( 'Post Ordering', 'papr-elements' ),
                'options' => array(
                    'DESC'  => esc_html__( 'Desecending', 'papr-elements' ),
                    'ASC'   => esc_html__( 'Ascending', 'papr-elements' ),
                ),
                'default' => 'DESC',
            ),               
            array (
                'type'      => Controls_Manager::SELECT2,
                'id'        => 'cat_single_list',
                'label'     => esc_html__( 'Categories', 'papr-elements' ),
                'options'   => $category_dropdown,
                'default'   => '0',
                'multiple'  => true,
               
            ),          
            array(
                'type'    => Controls_Manager::NUMBER,
                'id'      => 'number_of_post',
                'label'   => esc_html__( 'Number of Post', 'papr-elements' ),
                'default' => '4',               
            ),
            array(
                'type' => Controls_Manager::NUMBER,
                'id' => 'offset',
                'label' => esc_html__('Offset', 'papr-elements'),
            ),
            array(
                'type'    => Controls_Manager::SELECT2,
                'id'      => 'posts_not_in',
                'label'   => esc_html__( 'Select The Posts that will not display', 'papr-elements' ),
                'label_block'   => true,
                'multiple'      => true,
                'separator'     => 'before',
                'options'       => axil_post_name(),
            ),

        array(
                'mode' => 'section_end',
            ),
            array(
                'mode'    => 'section_start',
                'id'      => 'sec_meta_query',
                'label'   => esc_html__( 'Display Options', 'papr-elements' ),
            ),
            array(
                'type'    => Controls_Manager::CHOOSE,
                'id'      => 'post_title_tag',
                'label'   => esc_html__( 'Title HTML Tag', 'papr-elements' ),
                'options' => array(
                    'h1'  => [
                        'title' => esc_html__( 'H1', 'papr-elements' ),
                        'icon' => 'eicon-editor-h1'
                    ],
                    'h2'  => [
                        'title' => esc_html__( 'H2', 'papr-elements' ),
                        'icon' => 'eicon-editor-h2'
                    ],
                    'h3'  => [
                        'title' => esc_html__( 'H3', 'papr-elements' ),
                        'icon' => 'eicon-editor-h3'
                    ],
                    'h4'  => [
                        'title' => esc_html__( 'H4', 'papr-elements' ),
                        'icon' => 'eicon-editor-h4'
                    ],
                    'h5'  => [
                        'title' => esc_html__( 'H5', 'papr-elements' ),
                        'icon' => 'eicon-editor-h5'
                    ],
                    'h6'  => [
                        'title' => esc_html__( 'H6', 'papr-elements' ),
                        'icon' => 'eicon-editor-h6'
                    ],
                    'div'  => [
                        'title' => esc_html__( 'div', 'papr-elements' ),
                        'icon' => 'eicon-font'
                    ]
                ),
                'default' => 'h3',
                'toggle' => false,
            ),
            array(
                'type'    => Controls_Manager::NUMBER,
                'id'      => 'post_title_length',
                'label'   => esc_html__( 'Post Title Length', 'papr-elements' ),
                'default' => '10',
            ),
             array( 
                    'mode'      => 'group',
                    'type'      => Group_Control_Typography::get_type(),
                    'name'      => 'post_title_typography',                
                    'label'     => esc_html__( 'Post Title Typography', 'papr-elements' ),
                    'selector'  => '{{WRAPPER}} .axil-post-title',
                ),
            array(
                'type'          => Controls_Manager::SWITCHER,
                'id'            => 'content_display',
                'label'         => esc_html__( 'Show content Display', 'papr-elements' ),
                'label_on'      => esc_html__( 'Show', 'papr-elements' ),
                'label_off'     => esc_html__( 'Hide', 'papr-elements' ),
                'default'       => 'yes',
                'return_value'  => 'yes',
            ),  
            array(
                'type'    => Controls_Manager::NUMBER,
                'id'      => 'post_content_length',
                'label'   => esc_html__( 'Post Excerpt Length', 'papr-elements' ),
                'default' => '20',
                'condition' => array( 'content_display' => array( 'yes' ) ),
            ),
            array(
                'mode' => 'section_end',
            ),
            
        );
        return $fields;

    }

protected function _register_controls() {
    $fields = $this->axil_fields();
    foreach ( $fields as $field ) {
      if ( isset( $field['mode'] ) && $field['mode'] == 'section_start' ) {
        $id = $field['id'];
        unset( $field['id'] );
        unset( $field['mode'] );
        $this->start_controls_section( $id, $field );
      }
      elseif ( isset( $field['mode'] ) && $field['mode'] == 'section_end' ) {
        $this->end_controls_section();
      }
      elseif ( isset( $field['mode'] ) && $field['mode'] == 'group' ) {
        $type = $field['type'];
        unset( $field['mode'] );
        unset( $field['type'] );
        $this->add_group_control( $type, $field );
      }
      elseif ( isset( $field['mode'] ) && $field['mode'] == 'responsive' ) {
        $id = $field['id'];
        unset( $field['id'] );
        unset( $field['mode'] );
        $this->add_responsive_control( $id, $field );
      }
      else {
        $id = $field['id'];
        unset( $field['id'] );
        $this->add_control( $id, $field );
      }
    }
}

protected function render() {
    $settings = $this->get_settings();     
    $template = 'post-minimal-1';
    return Axil_Elements_Helper::axil_element_template( $template, $settings );
    }
}
