<?php
/**
 * @author  Axilweb
 * @since   1.0
 * @version 1.0
 * @package papr-elements
 */
use Elementor\Controls_Manager;
use Elementor\Plugin;
use Elementor\Widget_Base;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
class axil_post_multi_video extends Widget_Base {
    public $axil_name;
    public $axil_base;
    public $axil_category;
    public $axil_icon;
    public $axil_translate;
    public function __construct( $settings = [], $args = null ) {
        $this->axil_category = AXIL_ELEMENTS_PRFX . '-widgets'; // Category /@dev
        $this->axil_icon     = 'eicon-post-list';
        $this->axil_name = esc_html__( 'Papr Video Posts list', 'papr-elements' );
        $this->axil_base = 'axilnews-video-post-list';
        $this->axil_translate = array(
            'cols'  => array(
                '12' =>esc_html__( '1 Col', 'papr-elements' ),
                '6'  =>esc_html__( '2 Col', 'papr-elements' ),
                '4'  =>esc_html__( '3 Col', 'papr-elements' ),
                '3'  =>esc_html__( '4 Col', 'papr-elements' ),
                '2'  =>esc_html__( '6 Col', 'papr-elements' ),
            ),
        );
        parent::__construct( $settings, $args );
    }
    public function get_name() {
        return $this->axil_base;
    }
    public function get_title() {
        return $this->axil_name;
    }
    public function get_icon() {
        return $this->axil_icon;
    }
    public function get_categories() {
        return array( $this->axil_category );
    }
    public function axil_fields(){  
        $categories = get_categories();
        foreach ( $categories as $category ) {
            $category_dropdown[$category->slug] = $category->name;
        }       
        $fields = array(           
            array(
                'mode'    => 'section_start',
                'id'      => 'sec_general',
                'label'   => esc_html__( 'Section Title', 'papr-elements' ),
            ),                
          
            array(
                'label'         => esc_html__( 'Title Show', 'papr-elements' ),
                'type'          => Controls_Manager::SWITCHER,
                'id'            => 'has_sec_title',
                'label_on'      => esc_html__( 'Show', 'papr-elements' ),
                'label_off'     => esc_html__( 'Hide', 'papr-elements' ),
                'return_value'  => 'yes',
                'default'       => 'yes',               
            ),      
            array(
                'type'    => Controls_Manager::CHOOSE,
                'id'      => 'sec_title_tag',
                'label'   => esc_html__( 'Title HTML Tag', 'papr-elements' ),
                'options' => array(
                    'h1'  => [
                        'title' => esc_html__( 'H1', 'papr-elements' ),
                        'icon' => 'eicon-editor-h1'
                    ],
                    'h2'  => [
                        'title' => esc_html__( 'H2', 'papr-elements' ),
                        'icon' => 'eicon-editor-h2'
                    ],
                    'h3'  => [
                        'title' => esc_html__( 'H3', 'papr-elements' ),
                        'icon' => 'eicon-editor-h3'
                    ],
                    'h4'  => [
                        'title' => esc_html__( 'H4', 'papr-elements' ),
                        'icon' => 'eicon-editor-h4'
                    ],
                    'h5'  => [
                        'title' => esc_html__( 'H5', 'papr-elements' ),
                        'icon' => 'eicon-editor-h5'
                    ],
                    'h6'  => [
                        'title' => esc_html__( 'H6', 'papr-elements' ),
                        'icon' => 'eicon-editor-h6'
                    ],
                    'div'  => [
                        'title' => esc_html__( 'div', 'papr-elements' ),
                        'icon' => 'eicon-font'
                    ]
                ),
                'default' => 'h2',
                'toggle' => false,
                'label_block' => true,
                'condition' => array( 'has_sec_title' => array( 'yes' ) ),
            ),  
            array(
                'type'    => Controls_Manager::TEXTAREA,
                'id'      => 'title',
                'label'   => esc_html__( 'Title', 'papr-elements' ),
                'default' => 'News',
                'condition' => array( 'has_sec_title' => array( 'yes' ) ),
            ),
              array( 
                    'mode'      => 'group',
                    'type'      => Group_Control_Typography::get_type(),
                    'name'      => 'section_title_typography',                
                    'label'     => esc_html__( 'Typography', 'papr-elements' ),
                    'selector'  => '{{WRAPPER}} .axil-title',
                     'condition' => array( 'has_sec_title' => array( 'yes' ) ),
                ),
            array(
                'type'    => Controls_Manager::COLOR,
                'id'      => 'title_color',
                'label'   => esc_html__( 'Title Color', 'papr-elements' ),
                'selectors' => array(
                    '{{WRAPPER}} .title-white .axil-title' => 'color: {{VALUE}} !important',
                ),
                'condition' => array( 'has_sec_title' => array( 'yes' ) ),
            ),
            array(              
                'id'    => 'hr4',
                'type'  => Controls_Manager::DIVIDER,               
                'style' => 'thick',
            ),    
            array(
                'label'         => esc_html__( 'Title Button', 'papr-elements' ),
                'type'          => Controls_Manager::SWITCHER,
                'id'            => 'has_title_button',
                'label_on'      => esc_html__( 'Show', 'papr-elements' ),
                'label_off'     => esc_html__( 'Hide', 'papr-elements' ),
                'return_value'  => 'yes',
                'default'       => 'yes',                              
            ),      

             // Link Start
                array(
                    'id'        => 'axil_post_grid_link_text',
                    'label'     => esc_html__( 'Button Text', 'papr-elements' ),
                    'type'      => Controls_Manager::TEXT,
                    'default'   => 'View All Post',
                    'title'     => esc_html__( 'Enter button text', 'papr-elements' ),
                    'condition' => array( 'has_title_button' => array( 'yes' ) ),
                    
                ),
                array(
                    'id'        => 'axil_post_grid_link_type',
                    'label'     => esc_html__( 'Button Link Type', 'papr-elements' ),
                    'type'      => Controls_Manager::SELECT,
                    'condition' => array( 'has_title_button' => array( 'yes' ) ),
                    'options' => array(
                        '1' => esc_html__( 'Custom Link', 'papr-elements' ),
                        '2' => esc_html__( 'Internal Page', 'papr-elements' ),
                        '3' => esc_html__( 'News Category', 'papr-elements' ),
                        '4' => esc_html__( 'Post Format', 'papr-elements' ),
                       
                    ),
                    'default'   => '1',                    
                ),

                array(
                    'type'    => Controls_Manager::URL,
                    'id'      => 'axil_post_grid_custom_link',
                    'label'   => esc_html__( 'Button URL', 'papr-elements' ),
                    'placeholder' => 'https://your-link.com',
                    'default' => [
                        'url' => '#',
                        'is_external'   => true,
                        'nofollow'      => true,
                    ],
                   'condition' => array( 
                            'axil_post_grid_link_type' => array( '1' ),
                            'has_title_button' => array( 'yes' ),
                         ),
                ),                
                array(
                    'id'            => 'axil_post_grid_page_link',
                    'label'         => esc_html__( 'Select Button Page', 'papr-elements' ),
                    'type'          => Controls_Manager::SELECT2,                    
                    'options'       => axil_get_all_pages(),                   
                       'condition' => array( 
                            'axil_post_grid_link_type' => array( '2' ),
                            'has_title_button' => array( 'yes' ),
                         ),
                ),
                 array(
                        'id'            => 'axil_post_grid_cat_link',
                        'label'         => esc_html__( 'Select Category', 'papr-elements' ),
                        'type'          => Controls_Manager::SELECT2,                    
                        'options'   => $category_dropdown,                 
                           'condition' => array( 
                                'axil_post_grid_link_type' => array( '3' ),
                                'has_title_button' => array( 'yes' ),
                             ),
                    ),       

                 array(
                        'id'            => 'axil_post_grid_format_link',
                        'label'         => esc_html__( 'Select Post Format', 'papr-elements' ),
                        'type'          => Controls_Manager::SELECT2, 
                        'options'       => array(
                            'aside'     => esc_html__( 'Aside', 'papr-elements' ),
                            'gallery'   => esc_html__( 'Gallery', 'papr-elements' ),
                            'status'    => esc_html__( 'Status', 'papr-elements' ),
                            'video'     => esc_html__( 'video', 'papr-elements' ),
                            'audio'     => esc_html__( 'Audio', 'papr-elements' ),
                            ),  
                       'condition' => array( 
                                'axil_post_grid_link_type' => array( '4' ),
                                'has_title_button' => array( 'yes' ),
                             ),
                    ),       
                array(
                    'type'    => Controls_Manager::COLOR,
                    'id'      => 'axil_post_grid_link_color',
                    'label'   => esc_html__( 'Link Color', 'papr-elements' ),
                    'selectors' => array(
                        '{{WRAPPER}} .btn-link' => 'color: {{VALUE}} !important; border-color: {{VALUE}} !important',
                    ),
                    'condition' => array( 'has_title_button' => array( 'yes' ) ),
                ),
                array(
                    'type'    => Controls_Manager::COLOR,
                    'id'      => 'axil_post_grid_link_color_hover',
                    'label'   => esc_html__( 'Link Hover Color', 'papr-elements' ),
                    'selectors' => array(
                        '{{WRAPPER}} .btn-link:hover' => 'color: {{VALUE}} !important; border-color: {{VALUE}} !important',
                    ),
                    'condition' => array( 'has_title_button' => array( 'yes' ) ),
                ),
                  
            array(
                'mode' => 'section_end',
            ),

            array(
                'mode'    => 'section_start',
                'id'      => 'sec_layout',
                'label'   => esc_html__( 'Layout', 'papr-elements' ),
            ),                 
                array(
                    'type'    => Controls_Manager::SELECT2,
                    'id'      => 'style',
                    'label'   => esc_html__( 'Layout', 'papr-elements' ),
                    'options' => array(
                        'style1' => esc_html__( 'Layout 1', 'papr-elements' ),
                        'style2' => esc_html__( 'Layout 2', 'papr-elements' ),
                        
                    ),
                    'default' => 'style1',
                ),
            array(
                'mode' => 'section_end',
            ),

            array(
                'mode'    => 'section_start',
                'id'      => 'sec_query',
                'label'   => esc_html__( 'Query', 'papr-elements' ),
            ),
            array (
                'type'      => Controls_Manager::SELECT2,
                'id'        => 'cat_single_list',
                'label'     => esc_html__( 'Categories', 'papr-elements' ),
                'options'   => $category_dropdown,
                'default'   => '0',
                'multiple'  => true,
               
            ), 
            array(
                'type'    => Controls_Manager::SELECT2,
                'id'      => 'post_sorting',
                'label'   => esc_html__( 'Post Sorting', 'papr-elements' ),
                'options' => array(
                    'recent'        => esc_html__( 'Recent Post', 'papr-elements' ),
                    'rand'          => esc_html__( 'Random Post', 'papr-elements' ),
                    'modified'      => esc_html__( 'Last Modified Post', 'papr-elements' ),
                    'comment_count' => esc_html__( 'Most commented Post', 'papr-elements' ),
                    'view'          => esc_html__( 'Most viewed Post', 'papr-elements' ),
                ),
                'default' => 'recent',
            ),
                  
            array(
                'type'    => Controls_Manager::SELECT2,
                'id'      => 'post_ordering',
                'label'   => esc_html__( 'Post Ordering', 'papr-elements' ),
                'options' => array(
                    'DESC'  => esc_html__( 'Desecending', 'papr-elements' ),
                    'ASC'   => esc_html__( 'Ascending', 'papr-elements' ),
                ),
                'default' => 'DESC',
            ),          
                  
            array(
                'type'    => Controls_Manager::NUMBER,
                'id'      => 'number_of_post',
                'label'   => esc_html__( 'Number of Post', 'papr-elements' ),
                'default' => '5',               
            ),
            array(
                'type' => Controls_Manager::NUMBER,
                'id' => 'offset',
                'label' => esc_html__('Offset', 'papr-elements'),
            ),
            array(
                'type'    => Controls_Manager::SELECT2,
                'id'      => 'posts_not_in',
                'label'   => esc_html__( 'Select The Posts that will not display', 'papr-elements' ),
                'label_block'   => true,
                'multiple'      => true,
                'separator'     => 'before',
                'options'       => axil_post_name(),
            ),

            array(
                'mode' => 'section_end',
            ),
            array(
                'mode'    => 'section_start',
                'id'      => 'sec_meta_query',
                'label'   => esc_html__( 'Display Options', 'papr-elements' ),
            ),           
             array(
                'type'    => Controls_Manager::CHOOSE,
                'id'      => 'post_title_tag',
                'label'   => esc_html__( 'Title HTML Tag', 'papr-elements' ),
                'options' => array(
                    'h1'  => [
                        'title' => esc_html__( 'H1', 'papr-elements' ),
                        'icon' => 'eicon-editor-h1'
                    ],
                    'h2'  => [
                        'title' => esc_html__( 'H2', 'papr-elements' ),
                        'icon' => 'eicon-editor-h2'
                    ],
                    'h3'  => [
                        'title' => esc_html__( 'H3', 'papr-elements' ),
                        'icon' => 'eicon-editor-h3'
                    ],
                    'h4'  => [
                        'title' => esc_html__( 'H4', 'papr-elements' ),
                        'icon' => 'eicon-editor-h4'
                    ],
                    'h5'  => [
                        'title' => esc_html__( 'H5', 'papr-elements' ),
                        'icon' => 'eicon-editor-h5'
                    ],
                    'h6'  => [
                        'title' => esc_html__( 'H6', 'papr-elements' ),
                        'icon' => 'eicon-editor-h6'
                    ],
                    'div'  => [
                        'title' => esc_html__( 'div', 'papr-elements' ),
                        'icon' => 'eicon-font'
                    ]
                ),
                'default' => 'h3',
                'label_block' => true,
                'toggle' => false,
            ),

            array(
                'type'    => Controls_Manager::NUMBER,
                'id'      => 'post_title_length',
                'label'   => esc_html__( 'Post Title Length', 'papr-elements' ),
                'default' => '10',
            ),
             array( 
                    'mode'      => 'group',
                    'type'      => Group_Control_Typography::get_type(),
                    'name'      => 'post_title_typography',                
                    'label'     => esc_html__( 'Post Title Typography', 'papr-elements' ),
                    'selector'  => '{{WRAPPER}} .axil-post-title',
                ),

            array(              
                'id'    => 'hr-multi-video-1',
                'type'  => Controls_Manager::DIVIDER,               
                'style' => 'thick',
            ),
            array(
                'type'        => Controls_Manager::SWITCHER,
                'id'          => 'cat_display',
                'label'       => esc_html__( 'Category Name Display', 'papr-elements' ),
                'label_on'    => esc_html__( 'On', 'papr-elements' ),
                'label_off'   => esc_html__( 'Off', 'papr-elements' ),
                'default'     => 'yes',
                'condition' => array( 'has_sec_title' => array( 'yes' ) ),
            ),
           
            array(
                'type'        => Controls_Manager::SWITCHER,
                'id'          => 'post_date',
                'label'       => esc_html__( 'Display Post Date', 'papr-elements' ),
                'label_on'    => esc_html__( 'Show', 'papr-elements' ),
                'label_off'   => esc_html__( 'Hide', 'papr-elements' ),
                'default'     => 'yes',
            ),
            array(
                'type'        => Controls_Manager::SWITCHER,
                'id'          => 'post_author',
                'label'       => esc_html__( 'Display Author Name', 'papr-elements' ),
                'label_on'    => esc_html__( 'Show', 'papr-elements' ),
                'label_off'   => esc_html__( 'Hide', 'papr-elements' ),
                'default'     => 'yes',
            ),  

            array(
                'type'        => Controls_Manager::SWITCHER,
                'id'          => 'post_update_date',
                'label'       => esc_html__( 'Display Update Date', 'papr-elements' ),
                'label_on'    => esc_html__( 'Show', 'papr-elements' ),
                'label_off'   => esc_html__( 'Hide', 'papr-elements' ),
                'default'     => 'no',
            ),   
            array(
                'type'        => Controls_Manager::SWITCHER,
                'id'          => 'post_view',
                'label'       => esc_html__( 'Display post view', 'papr-elements' ),
                'label_on'    => esc_html__( 'Show', 'papr-elements' ),
                'label_off'   => esc_html__( 'Hide', 'papr-elements' ),
                'default'     => 'no',
            ),   
            array(
                'type'        => Controls_Manager::SWITCHER,
                'id'          => 'post_shares',
                'label'       => esc_html__( 'Display post shares', 'papr-elements' ),
                'label_on'    => esc_html__( 'Show', 'papr-elements' ),
                'label_off'   => esc_html__( 'Hide', 'papr-elements' ),
                'default'     => 'no',
            ),  
           
            array(
                'type'        => Controls_Manager::SWITCHER,
                'id'          => 'post_comment',
                'label'       => esc_html__( 'Display Comment Number', 'papr-elements' ),
                'label_on'    => esc_html__( 'Show', 'papr-elements' ),
                'label_off'   => esc_html__( 'Hide', 'papr-elements' ),
                'default'     => 'no',
            ),
            /*Hide Thumbnail*/    
            array(              
                'id'    => 'hr-multi-video-2',
                'type'  => Controls_Manager::DIVIDER,               
                'style' => 'thick',
            ),
            array(
                'type'        => Controls_Manager::SWITCHER,
                'id'          => 'show_preview_img',
                'label'       => esc_html__( 'Display Preview Image', 'papr-elements' ),
                'label_on'    => esc_html__( 'Show', 'papr-elements' ),
                'label_off'   => esc_html__( 'Hide', 'papr-elements' ),
                'default'     => 'no',
                'condition' => array( 'show_post_thumb' => array( 'yes' ) ),
            ),
            array(
                'mode' => 'section_end',
            ),
        );
        return $fields;

    }

  protected function _register_controls() {
    $fields = $this->axil_fields();
    foreach ( $fields as $field ) {
      if ( isset( $field['mode'] ) && $field['mode'] == 'section_start' ) {
        $id = $field['id'];
        unset( $field['id'] );
        unset( $field['mode'] );
        $this->start_controls_section( $id, $field );
      }
      elseif ( isset( $field['mode'] ) && $field['mode'] == 'section_end' ) {
        $this->end_controls_section();
      }
      elseif ( isset( $field['mode'] ) && $field['mode'] == 'group' ) {
        $type = $field['type'];
        unset( $field['mode'] );
        unset( $field['type'] );
        $this->add_group_control( $type, $field );
      }
      elseif ( isset( $field['mode'] ) && $field['mode'] == 'responsive' ) {
        $id = $field['id'];
        unset( $field['id'] );
        unset( $field['mode'] );
        $this->add_responsive_control( $id, $field );
      }
      else {
        $id = $field['id'];
        unset( $field['id'] );
        $this->add_control( $id, $field );
      }
    }
  }
    private function axil_scripts(){
        wp_enqueue_script( 'magnific-popup' );  
        wp_enqueue_style( 'magnific-popup' );   
    }
protected function render() {
        $settings = $this->get_settings();  
            $this -> axil_scripts();
            if ($settings['style'] == 'style2') {
                $template = 'post-video-list-2';
            } else if ($settings['style'] == 'style3') {
                $template = 'post-video-list-3';  
            } else {            
                $template = 'post-video-list-1';
            }

        return Axil_Elements_Helper::axil_element_template( $template, $settings );
    }
}
