<?php
/**
 * @author  Axilweb
 * @since   1.0
 * @version 1.0
 * @package papr-elements
 */

use Elementor\Controls_Manager;
use Elementor\Plugin;
use Elementor\Widget_Base;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
class axilNews_post_single_banner extends Widget_Base {
    public $axil_name;
    public $axil_base;
    public $axil_category;
    public $axil_icon;
    public $axil_translate;
    public function __construct( $settings = [], $args = null ) {
        $this->axil_category = AXIL_ELEMENTS_PRFX . '-widgets'; // Category /@dev
        $this->axil_icon     = 'eicon-post-excerpt';
        $this->axil_name = esc_html__( 'Papr Single Banner Posts', 'papr-elements' );
        $this->axil_base = 'axilnews-blog-post-banner';
        $this->axil_translate = array(
            'cols'  => array(
                '12' =>esc_html__( '1 Col', 'papr-elements' ),
                '6'  =>esc_html__( '2 Col', 'papr-elements' ),
                '4'  =>esc_html__( '3 Col', 'papr-elements' ),
                '3'  =>esc_html__( '4 Col', 'papr-elements' ),
                '2'  =>esc_html__( '6 Col', 'papr-elements' ),
            ),
        );
        parent::__construct( $settings, $args );
    }
    public function get_name() {
        return $this->axil_base;
    }
    public function get_title() {
        return $this->axil_name;
    }
    public function get_icon() {
        return $this->axil_icon;
    }
    public function get_categories() {
        return array( $this->axil_category );
    }
    public function axil_fields(){   
     
        $fields = array(               
            array(
                'mode'    => 'section_start',
                'id'      => 'sec_general',
                'label'   => __( 'Section Title', 'papr-elements' ),
            ),          
                 
                array(
                    'label'         => esc_html__( 'Section Title Show', 'papr-elements' ),
                    'type'          => Controls_Manager::SWITCHER,
                    'id'            => 'has_sec_title',
                    'label_on'      => esc_html__( 'Show', 'papr-elements' ),
                    'label_off'     => esc_html__( 'Hide', 'papr-elements' ),
                    'return_value'  => 'yes',
                    'default'       => 'yes',               
                ), 

                 array(
                    'type'    => Controls_Manager::CHOOSE,
                    'id'      => 'sec_title_tag',
                    'label'   => esc_html__( 'Title HTML Tag', 'papr-elements' ),
                    'options' => array(
                        'h1'  => [
                            'title' => esc_html__( 'H1', 'papr-elements' ),
                            'icon' => 'eicon-editor-h1'
                        ],
                        'h2'  => [
                            'title' => esc_html__( 'H2', 'papr-elements' ),
                            'icon' => 'eicon-editor-h2'
                        ],
                        'h3'  => [
                            'title' => esc_html__( 'H3', 'papr-elements' ),
                            'icon' => 'eicon-editor-h3'
                        ],
                        'h4'  => [
                            'title' => esc_html__( 'H4', 'papr-elements' ),
                            'icon' => 'eicon-editor-h4'
                        ],
                        'h5'  => [
                            'title' => esc_html__( 'H5', 'papr-elements' ),
                            'icon' => 'eicon-editor-h5'
                        ],
                        'h6'  => [
                            'title' => esc_html__( 'H6', 'papr-elements' ),
                            'icon' => 'eicon-editor-h6'
                        ],
                        'div'  => [
                            'title' => esc_html__( 'div', 'papr-elements' ),
                            'icon' => 'eicon-font'
                        ]
                    ),
                    'default' => 'h2',
                    'label_block' => true,
                    'toggle' => false,
                    'condition' => array( 'has_sec_title' => array( 'yes' ) ),
                ),  

                array(
                    'type'    => Controls_Manager::TEXTAREA,
                    'id'      => 'title',
                    'label'   => __( 'Title', 'papr-elements' ),
                    'default' => 'News',
                    'condition' => array( 'has_sec_title' => array( 'yes' ) ),
                ),
                array( 
                    'mode'      => 'group',
                    'type'      => Group_Control_Typography::get_type(),
                    'name'      => 'section_title_typography',                
                    'label'     => esc_html__( 'Typography', 'papr-elements' ),
                    'selector'  => '{{WRAPPER}} .axil-single-title',
                ),
                array(
                    'type'    => Controls_Manager::COLOR,
                    'id'      => 'title_color',
                    'label'   => __( 'Title Color', 'papr-elements' ),
                    'selectors' => array(
                        '{{WRAPPER}} .axil-single-title' => 'color: {{VALUE}}',
                    ),
                    'condition' => array( 'has_sec_title' => array( 'yes' ) ),
                ),
            array(
                'mode' => 'section_end',
            ),
            array(
                'mode'    => 'section_start',
                'id'      => 'sec_layout',
                'label'   => esc_html__( 'Layout', 'papr-elements' ),
            ),                 
                array(
                    'type'    => Controls_Manager::SELECT2,
                    'id'      => 'style',
                    'label'   => esc_html__( 'Style', 'papr-elements' ),
                    'options' => array(
                        'style1' => esc_html__( 'Style 1', 'papr-elements' ),                                               
                    ),
                    'default' => 'style1',
                ),
            array(
                'mode' => 'section_end',
            ),

            array(
                'mode'    => 'section_start',
                'id'      => 'sec_query',
                'label'   => esc_html__( 'Query', 'papr-elements' ),
            ),

                array(
                    'type'    => Controls_Manager::SELECT2,
                    'id'      => 'single_post_title',
                    'label'   => esc_html__( 'Select Posts', 'papr-elements' ),
                    'label_block' => true,
                    'multiple' => true,
                    'options' => axil_post_name(),

                ),
               
            array(
                'mode' => 'section_end',
            ),                   
        
            array(
                'mode'    => 'section_start',
                'id'      => 'sec_meta_query',
                'label'   => esc_html__( 'Display Options', 'papr-elements' ),
            ),   

               array(
                'type'    => Controls_Manager::CHOOSE,
                'id'      => 'post_title_tag',
                'label'   => esc_html__( 'Title HTML Tag', 'papr-elements' ),
                'options' => array(
                    'h1'  => [
                        'title' => esc_html__( 'H1', 'papr-elements' ),
                        'icon' => 'eicon-editor-h1'
                    ],
                    'h2'  => [
                        'title' => esc_html__( 'H2', 'papr-elements' ),
                        'icon' => 'eicon-editor-h2'
                    ],
                    'h3'  => [
                        'title' => esc_html__( 'H3', 'papr-elements' ),
                        'icon' => 'eicon-editor-h3'
                    ],
                    'h4'  => [
                        'title' => esc_html__( 'H4', 'papr-elements' ),
                        'icon' => 'eicon-editor-h4'
                    ],
                    'h5'  => [
                        'title' => esc_html__( 'H5', 'papr-elements' ),
                        'icon' => 'eicon-editor-h5'
                    ],
                    'h6'  => [
                        'title' => esc_html__( 'H6', 'papr-elements' ),
                        'icon' => 'eicon-editor-h6'
                    ],
                    'div'  => [
                        'title' => esc_html__( 'div', 'papr-elements' ),
                        'icon' => 'eicon-font'
                    ]
                ),
                'label_block' => true,
                'toggle' => false,
                'default' => 'h3',
            ),   
                array(
                    'type'    => Controls_Manager::NUMBER,
                    'id'      => 'post_title_length',
                    'label'   => __( 'Post Title Length', 'papr-elements' ),
                    'default' => '18',
                ),
                 array( 
                    'mode'      => 'group',
                    'type'      => Group_Control_Typography::get_type(),
                    'name'      => 'post_title_typography',                
                    'label'     => esc_html__( 'Post Title Typography', 'papr-elements' ),
                    'selector'  => '{{WRAPPER}} .axil-post-title',
                ),

                array(              
                    'id'    => 'hr4',
                    'type'  => Controls_Manager::DIVIDER,               
                    'style' => 'thick',
                ),    
                array(
                    'type'        => Controls_Manager::SWITCHER,
                    'id'          => 'content_display',
                    'label'       => __( 'Show content Display', 'papr-elements' ),
                    'label_on'    => __( 'Show', 'papr-elements' ),
                    'label_off'   => __( 'Hide', 'papr-elements' ),
                    'default'     => 'yes',
                ),  
                array(
                    'type'    => Controls_Manager::NUMBER,
                    'id'      => 'post_content_length',
                    'label'   => __( 'Post Excerpt Length', 'papr-elements' ),
                    'default' => '20',
                    'condition' => array( 'content_display' => array( 'yes' ) ),
                ),
                array(              
                    'id'    => 'hr-single-1',
                    'type'  => Controls_Manager::DIVIDER,               
                    'style' => 'thick',
                ),
                array(
                    'type'        => Controls_Manager::SWITCHER,
                    'id'          => 'cat_display',
                    'label'       => __( 'Category Name Display', 'papr-elements' ),
                    'label_on'    => __( 'On', 'papr-elements' ),
                    'label_off'   => __( 'Off', 'papr-elements' ),
                    'default'     => 'yes',                    
                ),
                array(              
                    'id'    => 'hr3',
                    'type'  => Controls_Manager::DIVIDER,               
                    'style' => 'thick',
                ),      
                array(
                    'type'        => Controls_Manager::SWITCHER,
                    'id'          => 'post_date',
                    'label'       => __( 'Display Post Date', 'papr-elements' ),
                    'label_on'    => __( 'Show', 'papr-elements' ),
                    'label_off'   => __( 'Hide', 'papr-elements' ),
                    'default'     => 'yes',
                    'return_value'  => 'yes',
                ), 
                array(
                    'type'        => Controls_Manager::SWITCHER,
                    'id'          => 'post_author',
                    'label'       => __( 'Display Author Name', 'papr-elements' ),
                    'label_on'    => __( 'Show', 'papr-elements' ),
                    'label_off'   => __( 'Hide', 'papr-elements' ),
                    'default'     => 'yes',
                    'return_value'  => 'yes',
                ),  
                array(
                    'type'        => Controls_Manager::SWITCHER,
                    'id'          => 'post_update_date',
                    'label'       => __( 'Display Update Date', 'papr-elements' ),
                    'label_on'    => __( 'Show', 'papr-elements' ),
                    'label_off'   => __( 'Hide', 'papr-elements' ),
                    'default'     => 'no',
                    'return_value'  => 'yes',
                ),   
                array(
                    'type'        => Controls_Manager::SWITCHER,
                    'id'          => 'post_view',
                    'label'       => __( 'Display post view', 'papr-elements' ),
                    'label_on'    => __( 'Show', 'papr-elements' ),
                    'label_off'   => __( 'Hide', 'papr-elements' ),
                    'default'     => 'yes',
                    'return_value'  => 'yes',
                ),   
                array(
                    'type'        => Controls_Manager::SWITCHER,
                    'id'          => 'post_shares',
                    'label'       => __( 'Display post shares', 'papr-elements' ),
                    'label_on'    => __( 'Show', 'papr-elements' ),
                    'label_off'   => __( 'Hide', 'papr-elements' ),
                    'default'     => 'yes',
                    'return_value'  => 'yes',
                ),                 
                array(
                    'type'        => Controls_Manager::SWITCHER,
                    'id'          => 'post_comment',
                    'label'       => __( 'Display Comment Number', 'papr-elements' ),
                    'label_on'    => __( 'Show', 'papr-elements' ),
                    'label_off'   => __( 'Hide', 'papr-elements' ),
                    'default'     => 'no',
                    'return_value'  => 'yes',
                ),              
                array(              
                    'id'    => 'hr2',
                    'type'  => Controls_Manager::DIVIDER,               
                    'style' => 'thick',
                ),      
                array(
                    'type'        => Controls_Manager::SWITCHER,
                    'id'          => 'show_post_thumb',
                    'label'       => __( 'Display Post Thumbnail', 'papr-elements' ),
                    'label_on'    => __( 'Show', 'papr-elements' ),
                    'label_off'   => __( 'hide', 'papr-elements' ),
                    'default'     => 'yes',
                    'condition' => array( 'style' => array( 'style1' ) ),
                ),    

            array(
                'mode' => 'section_end',
            ),
            
        );
        return $fields;

    }

  protected function _register_controls() {
    $fields = $this->axil_fields();
    foreach ( $fields as $field ) {
      if ( isset( $field['mode'] ) && $field['mode'] == 'section_start' ) {
        $id = $field['id'];
        unset( $field['id'] );
        unset( $field['mode'] );
        $this->start_controls_section( $id, $field );
      }
      elseif ( isset( $field['mode'] ) && $field['mode'] == 'section_end' ) {
        $this->end_controls_section();
      }
      elseif ( isset( $field['mode'] ) && $field['mode'] == 'group' ) {
        $type = $field['type'];
        unset( $field['mode'] );
        unset( $field['type'] );
        $this->add_group_control( $type, $field );
      }
      elseif ( isset( $field['mode'] ) && $field['mode'] == 'responsive' ) {
        $id = $field['id'];
        unset( $field['id'] );
        unset( $field['mode'] );
        $this->add_responsive_control( $id, $field );
      }
      else {
        $id = $field['id'];
        unset( $field['id'] );
        $this->add_control( $id, $field );
      }
    }
  }
protected function render() {
        $settings = $this->get_settings();            
        $template   = 'post-single-banner-' . str_replace("style", "", $settings['style']);
        return Axil_Elements_Helper::axil_element_template( $template, $settings );
    }
}
