<?php
/**
 * @author  Axilweb
 * @since   1.0
 * @version 1.0
 * @package papr-elements
 */
use Elementor\Controls_Manager;
use Elementor\Plugin;
use Elementor\Widget_Base;
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
class Team_Grid extends Widget_Base {
   
    public $axil_name;
    public $axil_base;
    public $axil_category;
    public $axil_icon;
    public $axil_translate;
    public function __construct( $settings = [], $args = null ) {
        
        $this->axil_category = AXIL_ELEMENTS_PRFX . '-widgets'; // Category /@dev
        $this->axil_icon     = 'eicon-person';
        $this->axil_name = esc_html__( 'Papr Team Grid', 'papr-elements' );
        $this->axil_base = 'axilnews-team-grid';
        	$this->axil_translate = array(
			'cols'  => array(
				'12' => esc_html__( '1 Col', 'papr-elements' ),
				'6'  => esc_html__( '2 Col', 'papr-elements' ),
				'4'  => esc_html__( '3 Col', 'papr-elements' ),
				'3'  => esc_html__( '4 Col', 'papr-elements' ),
				'2'  => esc_html__( '6 Col', 'papr-elements' ),
			),
		);
        parent::__construct( $settings, $args );
    }
    public function get_name() {
        return $this->axil_base;
    }
    public function get_title() {
        return $this->axil_name;
    }
    public function get_icon() {
        return $this->axil_icon;
    }
    public function get_categories() {
        return array( $this->axil_category );
    }
    public function axil_fields(){  
        $themepfix = AXIL_FIX_PRFX;		
        $terms  = get_terms( array( 'taxonomy' => "{$themepfix}_team_category") );
        if ( $terms && !is_wp_error( $terms )) {
            foreach ( $terms as $term ) {
               $category_dropdown[$term->slug] = $term->name;
            }
            
        }
        $fields = array(
            array(
                'mode'    => 'section_start',
                'id'      => 'sec_query',
                'label'   => esc_html__( 'Query', 'papr-elements' ),
            ),
                       
            array(
                'type'    => Controls_Manager::NUMBER,
                'id'      => 'number',
                'label'   =>  esc_html__( 'Total number of items', 'papr-elements' ),
                'default' => -1,
                'description' => esc_html__( 'Write -1 to show all', 'papr-elements' ),
            ),
            array(
                'type'    => Controls_Manager::SELECT2,
                'id'      => 'orderby',
                'label'   => esc_html__( 'Order By', 'papr-elements' ),
                'options' => array(
                    'date'        => esc_html__( 'Date (Recents comes first)', 'papr-elements' ),
                    'title'       => esc_html__( 'Title', 'papr-elements' ),
                    'menu_order'  => esc_html__( 'Custom Order (Available via Order field inside Page Attributes box)', 'papr-elements' ),
                ),
                'default' => 'date',
            ),
            array(
                'type' => Controls_Manager::NUMBER,
                'id' => 'offset',
                'label' => esc_html__('Offset', 'papr-elements'),
            ),
            array(
                'type'        => Controls_Manager::SWITCHER,
                'id'          => 'designation_display',
                'label'       => esc_html__( 'Designation Display', 'papr-elements' ),
                'label_on'    => esc_html__( 'On', 'papr-elements' ),
                'label_off'   => esc_html__( 'Off', 'papr-elements' ),
                'default'     => 'yes',
                'description' => esc_html__( 'Show or Hide Designation. Default: On', 'papr-elements' ),
            ),
            array(
                'type'        => Controls_Manager::SWITCHER,
                'id'          => 'social_display',
                'label'       => esc_html__( 'Social Media Display', 'papr-elements' ),
                'label_on'    => esc_html__( 'On', 'papr-elements' ),
                'label_off'   => esc_html__( 'Off', 'papr-elements' ),
                'default'     => 'yes',
                'description' => esc_html__( 'Show or Hide Social Medias. Default: On', 'papr-elements' ),
            ),
            array(
                'mode' => 'section_end',
            ),
            array(
                'mode'    => 'section_start',
                'id'      => 'sec_responsive',
                'label'   => esc_html__( 'Responsive Columns', 'papr-elements' ),
            ),
            array(
                'type'    => Controls_Manager::SELECT2,
                'id'      => 'col_lg',
                'label'   => esc_html__( 'Desktops: > 1199px', 'papr-elements' ),
                'options' => $this->axil_translate['cols'],
                'default' => '4',
            ),
            array(
                'type'    => Controls_Manager::SELECT2,
                'id'      => 'col_md',
                'label'   => esc_html__( 'Desktops: > 991px', 'papr-elements' ),
                'options' => $this->axil_translate['cols'],
                'default' => '6',
            ),
            array(
                'type'    => Controls_Manager::SELECT2,
                'id'      => 'col_sm',
                'label'   => esc_html__( 'Tablets: > 767px', 'papr-elements' ),
                'options' => $this->axil_translate['cols'],
                'default' => '12',
            ),           
            array(
                'mode' => 'section_end',
            ),            
            
        );
        return $fields;
    }
     protected function _register_controls() {
        $fields = $this->axil_fields();
        foreach ( $fields as $field ) {
          if ( isset( $field['mode'] ) && $field['mode'] == 'section_start' ) {
            $id = $field['id'];
            unset( $field['id'] );
            unset( $field['mode'] );
            $this->start_controls_section( $id, $field );
          }
          elseif ( isset( $field['mode'] ) && $field['mode'] == 'section_end' ) {
            $this->end_controls_section();
          }
          elseif ( isset( $field['mode'] ) && $field['mode'] == 'group' ) {
            $type = $field['type'];
            unset( $field['mode'] );
            unset( $field['type'] );
            $this->add_group_control( $type, $field );
          }
          elseif ( isset( $field['mode'] ) && $field['mode'] == 'responsive' ) {
            $id = $field['id'];
            unset( $field['id'] );
            unset( $field['mode'] );
            $this->add_responsive_control( $id, $field );
          }
          else {
            $id = $field['id'];
            unset( $field['id'] );
            $this->add_control( $id, $field );
          }
        }
      }
	private function axil_scripts(){
		wp_enqueue_style(  'owl-carousel' );
		wp_enqueue_style(  'owl-theme-default' );
		wp_enqueue_script( 'owl-carousel' );
	}
    protected function render() {
        $settings = $this->get_settings(); 
        $template = 'team-1';
        return Axil_Elements_Helper::axil_element_template( $template, $settings );
    }
}
