<?php
/**
 * @author  Axilweb
 * @since   1.0
 * @version 1.0
 * @package papr-elements
 */


use Elementor\Controls_Manager;
use Elementor\Plugin;
use Elementor\Widget_Base;
use Elementor\Group_Control_Typography;
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
class Title extends Widget_Base {  
    public $axil_name;
    public $axil_base;
    public $axil_category;
    public $axil_icon;
    public $axil_translate;
    public function __construct( $settings = [], $args = null ) {
        $this->axil_category = AXIL_ELEMENTS_PRFX . '-widgets'; // Category /@dev
        $this->axil_icon     = 'eicon-post-title';
        $this->axil_name = esc_html__( 'Papr Section Title', 'papr-elements' );

        $this->axil_base = 'axilnews-title';

        parent::__construct( $settings, $args );
    }
    public function get_name() {
        return $this->axil_base;
    }
    public function get_title() {
        return $this->axil_name;
    }
    public function get_icon() {
        return $this->axil_icon;
    }
    public function get_categories() {
        return array( $this->axil_category );
    }

    public function axil_fields(){
        
           $fields = array(
            array(
                'mode'    => 'section_start',
                'id'      => 'sec_general',
                'label'   => esc_html__( 'General', 'papr-elements' ),
            ),
            
             array(
                'type'    => Controls_Manager::CHOOSE,
                'id'      => 'sec_title_tag',
                'label'   => esc_html__( 'Title HTML Tag', 'papr-elements' ),
                'options' => array(
                    'h1'  => [
                        'title' => esc_html__( 'H1', 'papr-elements' ),
                        'icon' => 'eicon-editor-h1'
                    ],
                    'h2'  => [
                        'title' => esc_html__( 'H2', 'papr-elements' ),
                        'icon' => 'eicon-editor-h2'
                    ],
                    'h3'  => [
                        'title' => esc_html__( 'H3', 'papr-elements' ),
                        'icon' => 'eicon-editor-h3'
                    ],
                    'h4'  => [
                        'title' => esc_html__( 'H4', 'papr-elements' ),
                        'icon' => 'eicon-editor-h4'
                    ],
                    'h5'  => [
                        'title' => esc_html__( 'H5', 'papr-elements' ),
                        'icon' => 'eicon-editor-h5'
                    ],
                    'h6'  => [
                        'title' => esc_html__( 'H6', 'papr-elements' ),
                        'icon' => 'eicon-editor-h6'
                    ],
                    'div'  => [
                        'title' => esc_html__( 'div', 'papr-elements' ),
                        'icon' => 'eicon-font'
                    ]
                ),
                'default' => 'h2',
                'toggle' => false,

            ),  
            array(
                'type'    => Controls_Manager::TEXTAREA,
                'id'      => 'title',
                'label'   => __( 'Title', 'papr-elements' ),
                'default' => 'ALL RECENT NEWS',
                
            ),
            array(
                'type'    => Controls_Manager::COLOR,
                'id'      => 'title_color',
                'label'   => __( 'Title Color', 'papr-elements' ),
                'default' => '#000000',
                'selectors' => array(
                    '{{WRAPPER}} .axil-title' => 'color: {{VALUE}}',
                ),
                
            ),
            array( 
                'mode'      => 'group',
                'type'      => Group_Control_Typography::get_type(),
                'name'      => 'title_font_size',                
                'label'     => esc_html__( 'Icon Typography', 'papr-elements' ),
                'selector'  => '{{WRAPPER}} .axil-title',
            ),

            array(
                'type'              => Controls_Manager::SLIDER,
                'mode'              => 'responsive',
                'id'            => 'bottom_title_spacing',
                'label'         => __( 'Bottom Spacing', 'papr-elements' ),                
                'size_units' => array( 'px' ),              
                'default' => array(
                'unit' => 'px',
                'size' => 20,
                ),
                    'selectors' => array(
                        '{{WRAPPER}} .section-title' => 'margin-bottom: {{SIZE}}{{UNIT}}  !important;',                        
                    )
                ),

            array(
                'label'         => esc_html__( 'Title Button', 'papr-elements' ),
                'type'          => Controls_Manager::SWITCHER,
                'id'            => 'has_title_button',
                'label_on'      => esc_html__( 'Show', 'papr-elements' ),
                'label_off'     => esc_html__( 'Hide', 'papr-elements' ),
                'return_value'  => 'yes',
                'default'       => 'yes',    
                                        
            ),      

             // Link Start
                array(
                    'id'        => 'axil_post_grid_link_text',
                    'label'     => esc_html__( 'Button Text', 'papr-elements' ),
                    'type'      => Controls_Manager::TEXT,
                    'default'   => 'ALL RECENT NEWS',
                    'title'     => esc_html__( 'Enter button text', 'papr-elements' ),
                    'condition' => array( 'has_title_button' => array( 'yes' ) ) ,
                    
                ),
                array(
                    'id'        => 'axil_post_grid_link_type',
                    'label'     => esc_html__( 'Button Link Type', 'papr-elements' ),
                    'type'      => Controls_Manager::SELECT,
                    
                    'options' => array(
                        '1' => esc_html__( 'Custom Link', 'papr-elements' ),
                        '2' => esc_html__( 'Internal Page', 'papr-elements' ),
                       
                    ),
                    'default'   => '1',    
                     'condition' => array( 'has_title_button' => array( 'yes' ) ) ,                
                ),

                array(
                    'type'    => Controls_Manager::URL,
                    'id'      => 'axil_post_grid_custom_link',
                    'label'   => __( 'Button URL', 'papr-elements' ),
                    'placeholder' => 'https://your-link.com',
                   'condition' => array( 
                            'axil_post_grid_link_type' => array( '1' ),
                            'has_title_button' => array( 'yes' ),
                           
                         ),
                ),                
                array(
                    'id'            => 'axil_post_grid_page_link',
                    'label'         => esc_html__( 'Select Button Page', 'papr-elements' ),
                    'type'          => Controls_Manager::SELECT2,                    
                    'options'       => axil_get_all_pages(),                   
                       'condition' => array( 
                            'axil_post_grid_link_type' => array( '2' ),
                            'has_title_button' => array( 'yes' ),
                            
                         ),
                ),
            array(
                'mode' => 'section_end',
            ),
        );
        return $fields;
    }


  
  protected function _register_controls() {
    $fields = $this->axil_fields();
    foreach ( $fields as $field ) {
      if ( isset( $field['mode'] ) && $field['mode'] == 'section_start' ) {
        $id = $field['id'];
        unset( $field['id'] );
        unset( $field['mode'] );
        $this->start_controls_section( $id, $field );
      }
      elseif ( isset( $field['mode'] ) && $field['mode'] == 'section_end' ) {
        $this->end_controls_section();
      }
      elseif ( isset( $field['mode'] ) && $field['mode'] == 'group' ) {
        $type = $field['type'];
        unset( $field['mode'] );
        unset( $field['type'] );
        $this->add_group_control( $type, $field );
      }
      elseif ( isset( $field['mode'] ) && $field['mode'] == 'responsive' ) {
        $id = $field['id'];
        unset( $field['id'] );
        unset( $field['mode'] );
        $this->add_responsive_control( $id, $field );
      }
      else {
        $id = $field['id'];
        unset( $field['id'] );
        $this->add_control( $id, $field );
      }
    }
  }

    protected function render() {
        $settings = $this->get_settings();        
        $template   = 'title-1';
        return Axil_Elements_Helper::axil_element_template( $template, $settings );
    }
}
